==> gbsite-1.1.0.tar.gz: gbsite/templates/gb/gb_prodtechpage.php <==
	<table cellpadding="2" cellspacing="0" border="0" width="100%">
	<tr>
	<td width="100%">
	<font face="<?= $font_1 ?>" size="2">
	<p>Great Bridge offers world-class technical support to assist in managing your Great Bridge PostgreSQL deployments. Our experienced PostgreSQL engineers and technicians will work closely with you to ensure your database infrastructure is operating at optimal performance levels at all times.</p>
	</td>
	</tr>
	</table>
	<table cellpadding="2" cellspacing="0" border="0" width="100%">
	<tr>
	<td width="100%">
	<font face="<?= $font_1 ?>" size="2">
	<p><b><font color="<?= $color_6 ?>">Enterprise Technical Support Offerings</font></b></p>
	<p>
	<b>Premium Support:</b>
	<li>Annual contract
	<li>24x7 coverage
	<li>Unlimited phone and email incidents
	<li>4 named contacts
	<li>Immediate response
	<li>Assigned support team
	<li>Free software upgrades
	</p>
	<p>
	<b>Standard Support:</b>
	<li>Annual contract
	<li>8x5 coverage (M-F, 8am-6pm, excluding holidays)
	<li>Unlimited email and limited phone incidents
	<li>2 named contacts
	<li>Response within 1 business day
	<li>Free software upgrades
	</p>
	<p><i>All technical support packages include:</i></p>
	<p><b>Great Bridge PostgreSQL <i>for Linux</i></b> - a QA-tested CD release of the PostgreSQL 7.0.3 database server for multiple Linux platforms, with an automated, graphical installer for quick and easy installation and configuration, and professional-grade documentation.</p>
	<p>For pricing information or more details, please contact us at 757.233.5526 or <a href="mailto:sales@greatbridge.com">sales@greatbridge.com</a></p>
	</font>
	</td>
	<td valign="top">
	<img src="<?= $image_path ?>/gbpgsql_box.gif" width="100" height="127">
	<br>
	<font face="<?= $font_1 ?>" size="2"><i>All Great Bridge technical support packages include <a href="/product/prodgbpgsql.php">Great Bridge PostgreSQL</a> software, including CD and printed documentation.</i></font>
	</td>
	</tr>
	</table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/gb/gb_prodtechpage.php <==
	<table cellpadding="2" cellspacing="0" border="0" width="100%">
	<tr>
	<td width="100%">
	<font face="<?= $font_1 ?>" size="2">
	<p>Great Bridge offers world-class technical support to assist in managing your Great Bridge PostgreSQL deployments. Our experienced PostgreSQL engineers and technicians will work closely with you to ensure your database infrastructure is operating at optimal performance levels at all times.</p>
	</td>
	</tr>
	</table>
	<table cellpadding="4" cellspacing="0" border="0" width="100%">
	<tr>
	<td width="100%"><br>
	<font face="<?= $font_1 ?>" size="2">
	<p><b><font color="<?= $color_6 ?>">Enterprise Technical Support Offerings</font></b></p>
	<p>
	<b>Premium Support:</b>
	<li>Annual contract
	<li>24x7 coverage
	<li>Unlimited phone and email incidents
	<li>4 named contacts
	<li>Immediate response
	<li>Assigned support team
	<li>Free software upgrades
	</p>
	<p>
	<b>Standard Support:</b>
	<li>Annual contract
	<li>8x5 coverage (M-F, 8am-6pm, excluding holidays)
	<li>Unlimited email and limited phone incidents
	<li>2 named contacts
	<li>Response within 1 business day
	<li>Free software upgrades
	</p>
	<center><hr width="100%" size="1" align="center" noshade></center>
	<p><i>All technical support packages include:</i></p>
	<p><img src="<?= $image_path ?>/gbpgsql_box.gif" width="100" height="127" align="left"><b><a href="/product/prodgbpgsql.php">Great Bridge PostgreSQL <i>for Linux</i></a></b> - a QA-tested CD release of the PostgreSQL 7.0.3 database server for multiple Linux platforms, with an automated, graphical installer for quick and easy installation and configuration, and professional-grade documentation.</p>
	<p>For pricing information or more details, please contact us at 757.233.5526 or <a href="mailto:sales@greatbridge.com">sales@greatbridge.com</a></p>
	</font>
	</td>
	</tr>
	</table>
